"use client";

import Image from "next/image";
import { useRef } from "react";

import { motion, useScroll, useTransform } from "framer-motion";

function ImageMap() {
  const container = useRef<HTMLElement | null>(null);

  const { scrollYProgress } = useScroll({
    target: container,
    offset: ["start end", "end start"],
  });

  const y = useTransform(scrollYProgress, [0, 1], ["-10%", "10%"]);

  return (
    <div
      ref={container as React.RefObject<HTMLDivElement>}
      className="relative flex h-[534px] items-center justify-center overflow-hidden md:h-[534px]"
      style={{ clipPath: "polygon(0% 0, 100% 0%, 100% 100%, 0 100%)" }}
    >
      <div className="fixed left-0 top-0 h-screen w-full">
        <motion.div style={{ y }} className="relative h-full w-full">
          <Image
            src={"/images/request-job/map.png"}
            fill
            alt="image"
            style={{ objectFit: "cover" }}
          />
        </motion.div>
      </div>
    </div>
  );
}

export default ImageMap;
